<?php

namespace AustraliaPost\Extensions\Business\API\Wrapper;

use AustraliaPost\Extensions\Business\API\Wrapper\Connectors\Abstract_Connector;
use AustraliaPost\Helpers\Utilities;

class Price {

	private $endpoint = '/prices/items';
	private $connector;
	private $response;
	/** @var Price_Request $priceRequest */
	private $priceRequest;

	/**
	 * Account constructor.
	 *
	 * @param Abstract_Connector $connector
	 * @param $priceRequest
	 */

	public function __construct( $connector, $priceRequest ) {
		$this->connector = $connector;
		$this->priceRequest = $priceRequest;
	}


	public function getItemPrices($groupByReference = false) {
		$this->response = $this->connector->connect(
			$this->endpoint,
			'POST',
			$this->getPayload()
		);

		if (isset($this->response['errors'])) {
			return $this->response;
		}

		$prices = [];
		if (!isset($this->response['items'])) {
			return $prices;
		}

		$errors = $this->extractErrors();

		if (!is_array($this->response['items'])) {
			return $prices;
		}

		$prices = $this->response['items'];
		if ($groupByReference === true) {
			foreach ($prices as $item) {
				$prices[$item['item_reference']] = array_values($item['prices']);
			}

			if (isset($this->response['warnings'])) {
				$prices['warnings'] = $this->response['warnings'];
			}

			return $prices;
		}

		$finalPrices = [];
		foreach ($prices as $item){
			$finalPrices =  array_merge($finalPrices, array_values($item['prices']));
		}

		if (isset($this->response['warnings'])) {
			$finalPrices['warnings'] = $this->response['warnings'];
		}

		$finalPrices['errors'] = $errors;

		return $finalPrices;
	}

	private function getPayload() {
		$pricePayload = $this->priceRequest->getPayload();
		return Utilities::_json_encode($pricePayload);
	}

	private function extractErrors() {
		$errors = [];

		foreach($this->response['items'] as $item){
			if (!empty($item['errors'])) {
				foreach ($item['errors'] as $error) {
					$errors[] = $error;
				}
			}
		}
		return $errors;
	}


}


