<?php

namespace AustraliaPost\Extensions\Business\Endpoints;


class Endpoints_Factory {

	public static function boot()
	{
		foreach (self::available_endpoints() as $endpoint)
		{
			if (class_exists($endpoint)) {
				new $endpoint();
			}
		}
	}

	/**
	 * @param string $endpoint
	 *
	 * @return array|string
	 */
	public static function get_endpoints_nonce ($endpoint = '') {

		if ($endpoint !== '') {
			if (class_exists($endpoint)) {
				/** @var Abstract_Endpoint $endpoint */
				$endpointClass = new $endpoint();
				return wp_create_nonce( $endpointClass->action() );
			}
		}

		$nonce = [];
		foreach (self::available_endpoints() as $endpoint) {
			/** @var Abstract_Endpoint $endpoint */
			$endpointClass = new $endpoint();
			$nonce[$endpointClass->action()] = wp_create_nonce( $endpointClass->action() );
		}

		return $nonce;
	}

	/**
	 * @return string[]
	 */
	public static function available_endpoints() {
		return [
			Calculate_Prices_Endpoint::class,
			Calculate_Prices_With_Surcharges_Endpoint::class,
			Create_Shipments_Endpoint::class,
			Generate_Labels_Endpoint::class,
			Get_Labels_Url_Endpoint::class,
			Load_App_Data_Endpoint::class,
			Get_Tracking_Events_Endpoint::class,
			Get_Shipments_By_Date_Endpoint::class,
			Create_Order_From_Shipments_Endpoint::class,
			Get_Orders_Endpoint::class,
			Update_Order_Status_Endpoint::class,
			Verify_Credentials_Endpoint::class,
			Verify_Merchant_Token_Endpoint::class,
			Generate_Labels_By_Order_Endpoint::class,
			Delete_Shipment_Endpoint::class,
		];
	}

}
