<?php
namespace AustraliaPost\Extensions\Business\Orders;

use AustraliaPost\Extensions\Business\Helpers\Utilities;
use AustraliaPost\Extensions\Business\Endpoints\Endpoints_Factory;

class Order_Summary_Settings
{

	const SECTION = 'order-summary';

	/**
	 * The single instance of the class.
	 *
	 * @var Order_Summary_Settings
	 */
	protected static $_instance = null;

	/**
	 * @return Order_Summary_Settings
	 */
	public static function get_instance()
	{
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function __construct() {
		add_action( 'admin_enqueue_scripts', [$this, 'enqueue_admin_scripts'] );
		add_filter( 'woocommerce_get_sections_shipping', [$this, 'add_section'] );
		add_filter( 'woocommerce_get_settings_shipping', [$this, 'add_settings'], 10, 2 );

	}

	public function enqueue_admin_scripts($hook)
	{
		if (!isset($_GET['page']) || $_GET['page'] !== 'wc-settings') return;
		if (!isset($_GET['section']) || $_GET['section'] !== 'order-summary') return;

		wp_enqueue_script(self::SECTION . '-app', plugin_dir_url( __FILE__ ) . 'app/dist/app.js', [], AUSPOST_CURRENT_VERSION, true);
		wp_enqueue_style(self::SECTION . '-css', plugin_dir_url( __FILE__ ) . 'app/dist/css/app.css', [], AUSPOST_CURRENT_VERSION);
	}

	public function add_section( $sections ) {

		$sections[self::SECTION] = __( 'Australia Post Labels Orders', 'woocommerce-australia-post-pro' );
		return $sections;

	}

	public function add_settings( $settings, $current_section ) {

		if ( $current_section !== self::SECTION ) {
			return $settings;
		}

		$nonce = Endpoints_Factory::get_endpoints_nonce();
		$shipment_products = Utilities::get_postage_products();

		include 'views/placeholder.php';
		return [];

	}

}
